DoubleBufHelper

Struct DoubleBufHelper 

pub struct DoubleBufHelper<'a> { /* private fields */ }
A helper for working with a buffer split into 2. You can advance it forward (like you would do with buf=&buf[idx..])

Implementations

Source

impl<'a> DoubleBufHelper<'a>

pub fn new(buf: &'a [u8], buf2: &'a [u8]) -> Self

pub fn consume_variable( &mut self, len: usize, ) -> Result<(&'a [u8], &'a [u8]), usize>

Consume len bytes and return them as 2 slices. Advances the buffer forward if successful. On error returns how many bytes are missing.

pub fn consume<const N: usize>(&mut self) -> Result<[u8; N], usize>

Read N bytes and advance the buffer by N if successful. Error returns how many missing bytes are there.

pub fn get(&self) -> [&'a [u8]; 2]

pub fn read_u32_be(&mut self) -> Result<u32, usize>

Read 4 big endian bytes and advance the buffer by 4 if successful. Error returns how many missing bytes are there.

pub fn read_u8(&mut self) -> Option<u8>

Read 1 byte and advance. Returns 1

pub fn get_contiguous(&self, len: usize) -> Option<&'a [u8]>

Get a contiguous slice at the start if it exists.

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn advance(&mut self, offset: usize)

Advance it forward. If it was a single buffer this would be equivalent to buf=&buf[idx..]). If offset is too large, will set itself empty.

pub fn with_max_len(&self, max_len: usize) -> DoubleBufHelper<'a>

pub fn as_ioslices(&self, len_limit: usize) -> [IoSlice<'a>; 2]